Dose Certa — Diagnóstico de Calagem
Description: Diagnóstico comparativo de calagem: Moreira et al. (2025) + método estadual. Motor validado com 106 testes.

## Onde e O Que

Defina o estado, cultura e sistema de manejo.

Estado
Cultura
🫘 Soja
🌽 Milho
☕ Café
🫛 Feijão
🌿 Pastagem
🌲 Eucalipto
🌾 Trigo
Sistema de manejo
Abertura de Área Com incorporação profunda do calcário.
SPD Plantio direto — aplicação superficial.

## Análise do Solo

Insira os dados do laudo laboratorial.

Incluir camada 20-40 cm
Camada 0-20 cm
Ca cmolc/dm³
Mg cmolc/dm³
K cmolc/dm³ ou mg/dm³
Al cmolc/dm³
H+Al cmolc/dm³
Argila %
pH SMP
CTC lab cmolc/dm³ (opcional)
Camada 20-40 cm
Ca cmolc/dm³
Mg cmolc/dm³
K cmolc/dm³ ou mg/dm³
Al cmolc/dm³
H+Al cmolc/dm³
Argila %
pH SMP
CTC lab cmolc/dm³ (opcional)
Calculados em tempo real
CTC pH7 —
V% —
t efetiva —

## Calcário

Dados do corretivo que será utilizado.

CaO %
MgO %
PRNT %
Tipo: —
CaO+MgO: —

### Dados de Entrada

Necessidade de Calagem — Moreira et al. (2025)
—
t/ha

### Comparação na camada 0-20 cm (base comum entre métodos)

### Projeções de Ca e Mg pós-calagem

Camada | Ca atual |  | Ca projetado | Mg atual |  | Mg projetado | Ca/Mg | Mg sat%
--- | --- | --- | --- | --- | --- | --- | --- | ---

Aviso: Este diagnóstico é uma ferramenta de apoio à decisão. A recomendação final deve ser feita por engenheiro agrônomo habilitado.

Os métodos implementados seguem as publicações oficiais e calibrações regionais. Resultados dependem da qualidade dos dados de entrada.

Motor de cálculo validado com 106 testes automatizados + fuzz testing (10.000 iterações).

Dose Certa — Desenvolvido com base em Moreira et al. (2025), GMAP/UFLA. Consultoria científica: Prof. Silvino Guimarães Moreira.